@@ -22,15 +22,19 @@ from packagedcode import golang
 from packagedcode import haxe
 from packagedcode import maven
 from packagedcode import models
+from packagedcode import msi
 from packagedcode import npm
 from packagedcode import nuget
 from packagedcode import opam
 from packagedcode import phpcomposer
+from packagedcode import pubspec
 from packagedcode import pypi
 from packagedcode import readme
 from packagedcode import rpm
 from packagedcode import rubygems
 from packagedcode import win_pe
+from packagedcode import windows
+
 
 # Note: the order matters: from the most to the least specific
 # Package classes MUST be added to this list to be active
@@ -66,7 +70,6 @@ PACKAGE_TYPES = [
     pypi.PythonPackage,
     golang.GolangPackage,
     models.CabPackage,
-    models.MsiInstallerPackage,
     models.InstallShieldPackage,
     models.NSISInstallerPackage,
     nuget.NugetPackage,
@@ -82,6 +85,9 @@ PACKAGE_TYPES = [
     win_pe.WindowsExecutable,
     readme.ReadmePackage,
     build.MetadataBzl,
+    msi.MsiInstallerPackage,
+    windows.MicrosoftUpdateManifestPackage,
+    pubspec.PubspecPackage,
 ]
 
 PACKAGES_BY_TYPE = {cls.default_type: cls for cls in PACKAGE_TYPES}
@@ -166,7 +172,7 @@ def get_package_instance(scan_data):
     klas = get_package_class(scan_data)
     existing_fields = attr.fields_dict(klas)
 
-    extra_data = scan_data.get('extra_data')
+    extra_data = scan_data.get('extra_data', {}) or {}
     package_data = {}
 
     for key, value in scan_data.items():
