@@ -94,6 +94,8 @@ def print_version(ctx, param, value):
     if not value or ctx.resilient_parsing:
         return
     click.echo('ScanCode version ' + scancode_config.__version__)
+    click.echo('ScanCode Output Format version ' + scancode_config.__output_format_version__)
+    click.echo('SPDX License list version ' + scancode_config.spdx_license_list_version)
     ctx.exit()
 
 
@@ -194,15 +196,15 @@ def validate_depth(ctx, param, value):
     default=1,
     metavar='INT',
     help='Set the number of parallel processes to use. '
-         'Disable parallel processing if 0. Also disable threading if -1. ''[default: 1]',
+         'Disable parallel processing if 0. Also disable threading if -1. [default: 1]',
     help_group=cliutils.CORE_GROUP, sort_order=10, cls=PluggableCommandLineOption)
 
 @click.option('--timeout',
     type=float,
     default=DEFAULT_TIMEOUT,
     metavar='<secs>',
-    help='Stop an unfinished file scan after a timeout in seconds.  '
-         '[default: %d seconds]' % DEFAULT_TIMEOUT,
+    help='Stop an unfinished file scan after a timeout in seconds. '
+         f'[default: {DEFAULT_TIMEOUT} seconds]',
     help_group=cliutils.CORE_GROUP, sort_order=10, cls=PluggableCommandLineOption)
 
 @click.option('--quiet',
@@ -326,6 +328,14 @@ def validate_depth(ctx, param, value):
          'are stored. (By default temporary files are deleted when a scan is '
          'completed.)',
     help_group=cliutils.MISC_GROUP, sort_order=1000, cls=PluggableCommandLineOption)
+
+@click.option(
+    "--check-version/--no-check-version",
+    help="Whether to check for new versions. Defaults to true.",
+    default=True,
+    # not yet supported in Click 6.7 but added in PluggableCommandLineOption
+    hidden=True,
+    help_group=cliutils.MISC_GROUP, sort_order=1000, cls=PluggableCommandLineOption)
 def scancode(
     ctx,
     input,  # NOQA
@@ -343,6 +353,7 @@ def scancode(
     test_slow_mode,
     test_error_mode,
     keep_temp_files,
+    check_version,
     echo_func=echo_stderr,
     *args,
     **kwargs,
@@ -428,6 +439,14 @@ def scancode(
         cliutils.validate_option_dependencies(ctx)
         pretty_params = get_pretty_params(ctx, generic_paths=test_mode)
 
+        # warn for outdated version and/or check for updates
+        from scancode.outdated import check_scancode_version_locally
+        outdated = check_scancode_version_locally()
+
+        if not outdated and check_version:
+            from scancode.outdated import check_scancode_version_remotely
+            outdated = check_scancode_version_remotely()
+
         # run proper
         success, _results = run_scan(
             input=input,
@@ -448,14 +467,12 @@ def scancode(
             pretty_params=pretty_params,
             # results are saved to file, no need to get them back in a cli context
             return_results=False,
-            echo_func=echo_stderr,
+            echo_func=echo_func,
+            outdated=outdated,
             *args,
             **kwargs
         )
 
-        # check for updates
-        from scancode.outdated import check_scancode_version
-        outdated = check_scancode_version()
         if not quiet and outdated:
             echo_stderr(outdated, fg='yellow')
 
@@ -491,6 +508,7 @@ def run_scan(
     test_error_mode=False,
     pretty_params=None,
     plugin_options=plugin_options,
+    outdated=None,
     *args,
     **kwargs
 ):
@@ -828,8 +846,12 @@ def run_scan(
         cle.start_timestamp = start_timestamp
         cle.tool_name = 'scancode-toolkit'
         cle.tool_version = scancode_config.__version__
+        cle.output_format_version = scancode_config.__output_format_version__
         cle.notice = notice
         cle.options = pretty_params or {}
+        cle.extra_data['spdx_license_list_version'] = scancode_config.spdx_license_list_version
+        if outdated:
+            cle.extra_data['OUTDATED'] = outdated
 
         # TODO: this is weird: may be the timings should NOT be stored on the
         # codebase, since they exist in abstract of it??
